*************************************************************************
*** "Types of Social Networks and the Transition to Parenthood" *********
*** Data preparation and analyses ***************************************
*** The datasets used are available at www.pairfam.de (release 6.0) *****
************************************************************************* 

version 11
set more off

***************************************
*** Variables wave 1 ******************
***************************************

use "c:\daten\anchor1.dta", clear 

keep id igr19 sex_gen

save "c:\daten\sib.dta" 


***************************************
*** Variables wave 2 ******************
***************************************

use "c:\daten\anchor2.dta", clear

* Filtering of network persons (nuclear family, kin, friends & acquaintances)

recode net5p1 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter1) 
recode net5p2 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter2) 
recode net5p3 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter3) 
recode net5p4 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter4) 
recode net5p5 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter5) 
recode net5p6 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter6) 
recode net5p7 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter7) 
recode net5p8 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter8) 
recode net5p9 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter9) 
recode net5p10 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter10) 
recode net5p11 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter11) 
recode net5p12 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter12) 
recode net5p13 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter13) 
recode net5p14 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter14) 
recode net5p15 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter15) 
recode net5p16 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter16) 
recode net5p17 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter17) 
recode net5p18 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter18) 
recode net5p19 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter19) 
recode net5p20 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter20) 
recode net5p21 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter21) 
recode net5p22 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter22) 
recode net5p23 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter23) 
recode net5p24 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter24) 
recode net5p25 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter25) 
recode net5p26 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter26) 
recode net5p27 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter27) 
recode net5p28 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter28) 
recode net5p29 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter29) 
recode net5p30 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter30)


* Network size

egen size = anycount(netp1n netp2n netp3n netp4n netp5n netp6n netp7n netp8n netp9n netp10n netp11n netp12n netp13n netp14n netp15n netp16n ///
netp17n netp18n netp19n netp20n netp21n netp22n netp23n netp24n netp25n netp26n netp27n netp28n netp29n netp30n), values(1)


* Type of relationship 

egen bez_nw_size = anycount(net5p1 net5p2 net5p3 net5p4 net5p5 net5p6 net5p7 net5p8 net5p9 net5p10 net5p11 net5p12 net5p13 net5p14 net5p15 ///
net5p16 net5p17 net5p18 net5p19 net5p20 net5p21 net5p22 net5p23 net5p24 net5p25 net5p26 net5p27 net5p28 net5p29 net5p30), values(2/21)

egen nufam_size = anycount(net5p1 net5p2 net5p3 net5p4 net5p5 net5p6 net5p7 net5p8 net5p9 net5p10 net5p11 net5p12 net5p13 net5p14 net5p15 ///
net5p16 net5p17 net5p18 net5p19 net5p20 net5p21 net5p22 net5p23 net5p24 net5p25 net5p26 net5p27 net5p28 net5p29 ///
net5p30) if bez_nw_size > 0 & bez_nw_size < 31, values(3,4,12)

egen kin_size = anycount(net5p1 net5p2 net5p3 net5p4 net5p5 net5p6 net5p7 net5p8 net5p9 net5p10 net5p11 net5p12 net5p13 net5p14 net5p15 ///
net5p16 net5p17 net5p18 net5p19 net5p20 net5p21 net5p22 net5p23 net5p24 net5p25 net5p26 net5p27 net5p28 net5p29 ///
net5p30) if bez_nw_size > 0 & bez_nw_size < 31, values(5, 6, 7, 13, 14, 15, 16, 17, 18, 19, 20)

egen friend_size = anycount(net5p1 net5p2 net5p3 net5p4 net5p5 net5p6 net5p7 net5p8 net5p9 net5p10 net5p11 net5p12 net5p13 net5p14 net5p15 ///
net5p16 net5p17 net5p18 net5p19 net5p20 net5p21 net5p22 net5p23 net5p24 net5p25 net5p26 net5p27 net5p28 net5p29 ///
net5p30) if bez_nw_size > 0 & bez_nw_size < 31, values(2, 21)

gen p_nufam = nufam_size / bez_nw_size
gen p_kin = kin_size / bez_nw_size
gen p_friend = friend_size / bez_nw_size

replace p_nufam = 0 if bez_nw_size == 0 
replace p_kin = 0 if bez_nw_size == 0 
replace p_friend = 0 if bez_nw_size == 0

 
* Average age of network

recode net10p1 net10p2 net10p3 net10p4 net10p5 net10p6 net10p7 net10p8 net10p9 net10p10 net10p11 net10p12 net10p13 net10p14 net10p15 ///
net10p16 net10p17 net10p18 net10p19 net10p20 net10p21 net10p22 net10p23 net10p24 net10p25 net10p26 net10p27 net10p28 ///
net10p30 (-5/-1 = .) 

gen age1 = net10p1 if filter1 == 1
gen age2 = net10p2 if filter2 == 1
gen age3 = net10p3 if filter3 == 1
gen age4 = net10p4 if filter4 == 1
gen age5 = net10p5 if filter5 == 1
gen age6 = net10p6 if filter6 == 1
gen age7 = net10p7 if filter7 == 1
gen age8 = net10p8 if filter8 == 1
gen age9 = net10p9 if filter9 == 1
gen age10 = net10p10 if filter10 == 1
gen age11 = net10p11 if filter11 == 1
gen age12 = net10p12 if filter12 == 1
gen age13 = net10p13 if filter13 == 1
gen age14 = net10p14 if filter14 == 1
gen age15 = net10p15 if filter15 == 1
gen age16 = net10p16 if filter16 == 1
gen age17 = net10p17 if filter17 == 1
gen age18 = net10p18 if filter18 == 1
gen age19 = net10p19 if filter19 == 1
gen age20 = net10p20 if filter20 == 1
gen age21 = net10p21 if filter21 == 1
gen age22 = net10p22 if filter22 == 1
gen age23 = net10p23 if filter23 == 1
gen age24 = net10p24 if filter24 == 1
gen age25 = net10p25 if filter25 == 1
gen age26 = net10p26 if filter26 == 1
gen age27 = net10p27 if filter27 == 1
gen age28 = net10p28 if filter28 == 1
gen age30 = net10p30 if filter30 == 1

egen avg_age = rowmean(age1 age2 age3 age4 age5 age6 age7 age8 age9 age10 age11 age12 age13 age14 age15 age16 age17 age18 age19 age20 ///
age21 age22 age23 age24 age25 age26 age27 age28 age30)

egen agesd = rowsd(age1 age2 age3 age4 age5 age6 age7 age8 age9 age10 age11 age12 age13 age14 age15 age16 age17 age18 age19 age20 ///
age21 age22 age23 age24 age25 age26 age27 age28 age30)


* Average duration of relationship 

recode net13p1 net13p2 net13p3 net13p4 net13p5 net13p6 net13p7 net13p8 net13p9 net13p10 net13p11 net13p12 net13p13 net13p14 ///
net13p15 net13p16 net13p17 net13p18 net13p19 net13p20 net13p21 net13p22 net13p23 net13p24 net13p25 net13p26 net13p27 ///
net13p28 net13p30 (97 = 0)

recode net13p1 net13p2 net13p3 net13p4 net13p5 net13p6 net13p7 net13p8 net13p9 net13p10 net13p11 net13p12 net13p13 net13p14 ///
net13p15 net13p16 net13p17 net13p18 net13p19 net13p20 net13p21 net13p22 net13p23 net13p24 net13p25 net13p26 net13p27 ///
net13p28 net13p30 (-5/-1 = .) 

gen dur1 = net13p1 if filter1 == 1
gen dur2 = net13p2 if filter2 == 1
gen dur3 = net13p3 if filter3 == 1
gen dur4 = net13p4 if filter4 == 1
gen dur5 = net13p5 if filter5 == 1
gen dur6 = net13p6 if filter6 == 1
gen dur7 = net13p7 if filter7 == 1
gen dur8 = net13p8 if filter8 == 1
gen dur9 = net13p9 if filter9 == 1
gen dur10 = net13p10 if filter10 == 1
gen dur11 = net13p11 if filter11 == 1
gen dur12 = net13p12 if filter12 == 1
gen dur13 = net13p13 if filter13 == 1
gen dur14 = net13p14 if filter14 == 1
gen dur15 = net13p15 if filter15 == 1
gen dur16 = net13p16 if filter16 == 1
gen dur17 = net13p17 if filter17 == 1
gen dur18 = net13p18 if filter18 == 1
gen dur19 = net13p19 if filter19 == 1
gen dur20 = net13p20 if filter20 == 1
gen dur21 = net13p21 if filter21 == 1
gen dur22 = net13p22 if filter22 == 1
gen dur23 = net13p23 if filter23 == 1
gen dur24 = net13p24 if filter24 == 1
gen dur25 = net13p25 if filter25 == 1
gen dur26 = net13p26 if filter26 == 1
gen dur27 = net13p27 if filter27 == 1
gen dur28 = net13p28 if filter28 == 1
gen dur30 = net13p30 if filter30 == 1

egen avg_dur = rowmean(dur1 dur2 dur3 dur4 dur5 dur6 dur7 dur8 dur9 dur10 dur11 dur12 dur13 dur14 dur15 dur16 dur17 dur18 dur19 dur20 ///
dur21 dur22 dur23 dur24 dur25 dur26 dur27 dur28 dur30)


* Average emotional closeness 

recode net7p1 net7p2 net7p3 net7p4 net7p5 net7p6 net7p7 net7p8 net7p9 net7p10 net7p11 net7p12 net7p13 net7p14 net7p15 net7p16 net7p17 /// 
net7p18 net7p19 net7p20 net7p21 net7p22 net7p23 net7p24 net7p25 net7p26 net7p27 net7p28 net7p30 (-5/-1 = .)

gen nah1 = net7p1 if filter1 == 1
gen nah2 = net7p2 if filter2 == 1
gen nah3 = net7p3 if filter3 == 1
gen nah4 = net7p4 if filter4 == 1
gen nah5 = net7p5 if filter5 == 1
gen nah6 = net7p6 if filter6 == 1
gen nah7 = net7p7 if filter7 == 1
gen nah8 = net7p8 if filter8 == 1
gen nah9 = net7p9 if filter9 == 1
gen nah10 = net7p10 if filter10 == 1
gen nah11 = net7p11 if filter11 == 1
gen nah12 = net7p12 if filter12 == 1
gen nah13 = net7p13 if filter13 == 1
gen nah14 = net7p14 if filter14 == 1
gen nah15 = net7p15 if filter15 == 1
gen nah16 = net7p16 if filter16 == 1
gen nah17 = net7p17 if filter17 == 1
gen nah18 = net7p18 if filter18 == 1
gen nah19 = net7p19 if filter19 == 1
gen nah20 = net7p20 if filter20 == 1
gen nah21 = net7p21 if filter21 == 1
gen nah22 = net7p22 if filter22 == 1
gen nah23 = net7p23 if filter23 == 1
gen nah24 = net7p24 if filter24 == 1
gen nah25 = net7p25 if filter25 == 1
gen nah26 = net7p26 if filter26 == 1
gen nah27 = net7p27 if filter27 == 1
gen nah28 = net7p28 if filter28 == 1
gen nah30 = net7p30 if filter30 == 1


egen avg_close = rowmean(nah1 nah2 nah3 nah4 nah5 nah6 nah7 nah8 nah9 nah10 nah11 nah12 nah13 nah14 nah15 nah16 nah17 nah18 nah19 nah20 ///
nah21 nah22 nah23 nah24 nah25 nah26 nah27 nah28 nah30)


* Potential for emotional contagion 

gen cont1 = 1 if net10p1 > 13 & net10p1 < 46 & (net5p1 == 12 | net5p1 == 14 | net5p1 == 15 | net5p1 == 16 | net5p1 == 17 | net5p1 == 19 | ///
net5p1 == 20 | net5p1 == 21) 

gen cont2 = 1 if net10p2 > 13 & net10p2 < 46 & (net5p2 == 12 | net5p2 == 14 | net5p2 == 15 | net5p2 == 16 | net5p2 == 17 | net5p2 == 19 | ///
net5p2 == 20 | net5p2 == 21)

gen cont3 = 1 if net10p3 > 13 & net10p3 < 46 & (net5p3 == 12 | net5p3 == 14 | net5p3 == 15 | net5p3 == 16 | net5p3 == 17 | net5p3 == 19 | ///
net5p3 == 20 | net5p3 == 21)

gen cont4 = 1 if net10p4 > 13 & net10p4 < 46 & (net5p4 == 12 | net5p4 == 14 | net5p4 == 15 | net5p4 == 16 | net5p4 == 17 | net5p4 == 19 | ///
net5p4 == 20 | net5p4 == 21)

gen cont5 = 1 if net10p5 > 13 & net10p5 < 46 & (net5p5 == 12 | net5p5 == 14 | net5p5 == 15 | net5p5 == 16 | net5p5 == 17 | net5p5 == 19 | ///
net5p5 == 20 | net5p5 == 21)

gen cont6 = 1 if net10p6 > 13 & net10p6 < 46 & (net5p6 == 12 | net5p6 == 14 | net5p6 == 15 | net5p6 == 16 | net5p6 == 17 | net5p6 == 19 | ///
net5p6 == 20 | net5p6 == 21)

gen cont7 = 1 if net10p7 > 13 & net10p7 < 46 & (net5p7 == 12 | net5p7 == 14 | net5p7 == 15 | net5p7 == 16 | net5p7 == 17 | net5p7 == 19 | ///
net5p7 == 20 | net5p7 == 21)

gen cont8 = 1 if net10p8 > 13 & net10p8 < 46 & (net5p8 == 12 | net5p8 == 14 | net5p8 == 15 | net5p8 == 16 | net5p8 == 17 | net5p8 == 19 | ///
net5p8 == 20 | net5p8 == 21)

gen cont9 = 1 if net10p9 > 13 & net10p9 < 46 & (net5p9 == 12 | net5p9 == 14 | net5p9 == 15 | net5p9 == 16 | net5p9 == 17 | net5p9 == 19 | ///
net5p9 == 20 | net5p9 == 21)

gen cont10 = 1 if net10p10 > 13 & net10p10 < 46 & (net5p10 == 12 | net5p10 == 14 | net5p10 == 15 | net5p10 == 16 | net5p10 == 17 | net5p10 == 19 | ///
net5p10 == 20 | net5p10 == 21)

gen cont11 = 1 if net10p11 > 13 & net10p11 < 46 & (net5p11 == 12 | net5p11 == 14 | net5p11 == 15 | net5p11 == 16 | net5p11 == 17 | net5p11 == 19 | ///
net5p11 == 20 | net5p11 == 21)

gen cont12 = 1 if net10p12 > 13 & net10p12 < 46 & (net5p12 == 12 | net5p12 == 14 | net5p12 == 15 | net5p12 == 16 | net5p12 == 17 | net5p12 == 19 | ///
net5p12 == 20 | net5p12 == 21)

gen cont13 = 1 if net10p13 > 13 & net10p13 < 46 & (net5p13 == 12 | net5p13 == 14 | net5p13 == 15 | net5p13 == 16 | net5p13 == 17 | net5p13 == 19 | ///
net5p13 == 20 | net5p13 == 21)

gen cont14 = 1 if net10p14 > 13 & net10p14 < 46 & (net5p14 == 12 | net5p14 == 14 | net5p14 == 15 | net5p14 == 16 | net5p14 == 17 | net5p14 == 19 | ///
net5p14 == 20 | net5p14 == 21)

gen cont15 = 1 if net10p15 > 13 & net10p15 < 46 & (net5p15 == 12 | net5p15 == 14 | net5p15 == 15 | net5p15 == 16 | net5p15 == 17 | net5p15 == 19 | ///
net5p15 == 20 | net5p15 == 21)

gen cont16 = 1 if net10p16 > 13 & net10p16 < 46 & (net5p16 == 12 | net5p16 == 14 | net5p16 == 15 | net5p16 == 16 | net5p16 == 17 | net5p16 == 19 | ///
net5p16 == 20 | net5p16 == 21)

gen cont17 = 1 if net10p17 > 13 & net10p17 < 46 & (net5p17 == 12 | net5p17 == 14 | net5p17 == 15 | net5p17 == 16 | net5p17 == 17 | net5p17 == 19 | ///
net5p17 == 20 | net5p17 == 21)

gen cont18 = 1 if net10p18 > 13 & net10p18 < 46 & (net5p18 == 12 | net5p18 == 14 | net5p18 == 15 | net5p18 == 16 | net5p18 == 17 | net5p18 == 19 | ///
net5p18 == 20 | net5p18 == 21)

gen cont19 = 1 if net10p19 > 13 & net10p19 < 46 & (net5p19 == 12 | net5p19 == 14 | net5p19 == 15 | net5p19 == 16 | net5p19 == 17 | net5p19 == 19 | ///
net5p19 == 20 | net5p19 == 21)

gen cont20 = 1 if net10p20 > 13 & net10p20 < 46 & (net5p20 == 12 | net5p20 == 14 | net5p20 == 15 | net5p20 == 16 | net5p20 == 17 | net5p20 == 19 | ///
net5p20 == 20 | net5p20 == 21)

gen cont21 = 1 if net10p21 > 13 & net10p21 < 46 & (net5p21 == 12 | net5p21 == 14 | net5p21 == 15 | net5p21 == 16 | net5p21 == 17 | net5p21 == 19 | ///
net5p21 == 20 | net5p21 == 21)

gen cont22 = 1 if net10p22 > 13 & net10p22 < 46 & (net5p22 == 12 | net5p22 == 14 | net5p22 == 15 | net5p22 == 16 | net5p22 == 17 | net5p22 == 19 | ///
net5p22 == 20 | net5p22 == 21)

gen cont23 = 1 if net10p23 > 13 & net10p23 < 46 & (net5p23 == 12 | net5p23 == 14 | net5p23 == 15 | net5p23 == 16 | net5p23 == 17 | net5p23 == 19 | ///
net5p23 == 20 | net5p23 == 21)

gen cont24 = 1 if net10p24 > 13 & net10p24 < 46 & (net5p24 == 12 | net5p24 == 14 | net5p24 == 15 | net5p24 == 16 | net5p24 == 17 | net5p24 == 19 | ///
net5p24 == 20 | net5p24 == 21)

gen cont25 = 1 if net10p25 > 13 & net10p25 < 46 & (net5p25 == 12 | net5p25 == 14 | net5p25 == 15 | net5p25 == 16 | net5p25 == 17 | net5p25 == 19 | ///
net5p25 == 20 | net5p25 == 21)

gen cont26 = 1 if net10p26 > 13 & net10p26 < 46 & (net5p26 == 12 | net5p26 == 14 | net5p26 == 15 | net5p26 == 16 | net5p26 == 17 | net5p26 == 19 | ///
net5p26 == 20 | net5p26 == 21)

gen cont27 = 1 if net10p27 > 13 & net10p27 < 46 & (net5p27 == 12 | net5p27 == 14 | net5p27 == 15 | net5p27 == 16 | net5p27 == 17 | net5p27 == 19 | ///
net5p27 == 20 | net5p27 == 21)

gen cont28 = 1 if net10p28 > 13 & net10p28 < 46 & (net5p28 == 12 | net5p28 == 14 | net5p28 == 15 | net5p28 == 16 | net5p28 == 17 | net5p28 == 19 | ///
net5p28 == 20 | net5p28 == 21)

recode net12p1-net12p23 (-7/-1=.)
recode net12p25-net12p26 (-7/-1=.)
recode net12p28 (-7/-1=.)

gen cont_1 = net12p1 if cont1 == 1
gen cont_2 = net12p2 if cont2 == 1
gen cont_3 = net12p3 if cont3 == 1
gen cont_4 = net12p4 if cont4 == 1
gen cont_5 = net12p5 if cont5 == 1
gen cont_6 = net12p6 if cont6 == 1
gen cont_7 = net12p7 if cont7 == 1
gen cont_8 = net12p8 if cont8 == 1
gen cont_9 = net12p9 if cont9 == 1
gen cont_10 = net12p10 if cont10 == 1
gen cont_11 = net12p11 if cont11 == 1
gen cont_12 = net12p12 if cont12 == 1
gen cont_13 = net12p13 if cont13 == 1
gen cont_14 = net12p14 if cont14 == 1
gen cont_15 = net12p15 if cont15 == 1
gen cont_16 = net12p16 if cont16 == 1
gen cont_17 = net12p17 if cont17 == 1
gen cont_18 = net12p18 if cont18 == 1
gen cont_19 = net12p19 if cont19 == 1
gen cont_20 = net12p20 if cont20 == 1
gen cont_21 = net12p21 if cont21 == 1
gen cont_22 = net12p22 if cont22 == 1
gen cont_23 = net12p23 if cont23 == 1
gen cont_25 = net12p25 if cont25 == 1
gen cont_26 = net12p26 if cont26 == 1
gen cont_28 = net12p28 if cont28 == 1

egen cont_nw_size = anycount(cont_1 cont_2 cont_3 cont_4 cont_5 cont_6 cont_7 cont_8 cont_9 cont_10 cont_11 cont_12 cont_13 cont_14 cont_15 ///
cont_16 cont_17 cont_18 cont_19 cont_20 cont_21 cont_22 cont_23 cont_25 cont_26 cont_28), values(0/5) 

egen n_nw_kids = anycount(cont_1 cont_2 cont_3 cont_4 cont_5 cont_6 cont_7 cont_8 cont_9 cont_10 cont_11 cont_12 cont_13 cont_14 cont_15 ///
cont_16 cont_17 cont_18 cont_19 cont_20 cont_21 cont_22 cont_23 cont_25 cont_26 cont_28), values(1/5)

gen p_contag = n_nw_kids / cont_nw_size

replace p_contag = 0 if cont_nw_size == 0

recode p_contag (else = .) if age < 18

egen m_contag = rowmean(cont_1 cont_2 cont_3 cont_4 cont_5 cont_6 cont_7 cont_8 cont_9 cont_10 cont_11 cont_12 cont_13 cont_14 cont_15 ///
cont_16 cont_17 cont_18 cont_19 cont_20 cont_21 cont_22 cont_23 cont_25 cont_26 cont_28)

replace p_contag = . if m_contag == .


* Diversity
 
recode net5p1 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p1)
recode net5p2 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p2)
recode net5p3 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p3)
recode net5p4 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p4)
recode net5p5 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p5)
recode net5p6 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p6)
recode net5p7 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p7)
recode net5p8 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p8)
recode net5p9 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p9)
recode net5p10 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p10)
recode net5p11 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p11)
recode net5p12 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p12)
recode net5p13 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p13)
recode net5p14 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p14)
recode net5p15 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p15)
recode net5p16 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p16)
recode net5p17 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p17)
recode net5p18 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p18)
recode net5p19 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p19)
recode net5p20 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p20)
recode net5p21 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p21)
recode net5p22 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p22)
recode net5p23 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p23)
recode net5p24 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p24)
recode net5p25 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p25)
recode net5p26 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p26)
recode net5p27 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p27)
recode net5p28 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p28)
recode net5p29 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p29)
recode net5p30 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p30)


* Social pressure (global question)

recode frt10i1 frt10i2 (-5/-1 = .) 
 
corr frt10i1 frt10i2

egen pressure = rowmean(frt10i1 frt10i2)



* Social support (global question)

recode frt20i1 frt20i2 frt20i3 (-5/-1=.) 

alpha frt20i1 frt20i2 frt20i3, item  

egen support = rowmean(frt20i1 frt20i2 frt20i3)


* Saving results 

gen filter_w2 = 1 
replace filter_w2 = 0 if homosex == 1 | pregnant == 1 | nkids > 0 | nkids == -7 | infertile == 1 | age < 20

keep if filter_w2 == 1

keep id size p_nufam p_kin p_friend avg_age agesd avg_dur avg_close p_contag m_contag pressure support rt_p1-rt_p30 ///
age ethni migstatus relstat yeduc enrol east filter_w2

save "c:\daten\var_wave2.dta"

keep id filter_w2

save "c:\daten\filter2.dta"


* Computing "index of qualitative variation" 

use "c:\daten\var_wave2.dta" 

keep id rt_p1-rt_p30

reshape long rt_p, i(id) j(np)

gen ntyp = 0
replace ntyp = 1 if rt_p <= 3
by id: replace ntyp = sum(ntyp)
by id: replace ntyp = ntyp[_N]

local i = 1
while `i' < 4 {
gen pbt_k`i' = 1 if rt_p == `i'
by id: replace pbt_k`i' = sum(pbt_k`i')/ntyp
by id: replace pbt_k`i' = pbt_k`i'[_N]
local i = `i' + 1
}

gen helpv = pbt_k1^2+pbt_k2^2+pbt_k3^2
gen helpv2 = 1
gen dbt = helpv2-helpv 

gen iqv = 3/2*dbt

by id: gen ln = _n

keep if ln == 1
keep id iqv 

save "c:\daten\iqv_w2.dta" 


***************************************
*** Variables wave 3 ******************
***************************************

use "c:\daten\anchor3.dta", clear 

keep if demodiff == 0

egen family3 = anycount(crn3k1-crn3k6), values(-2,1,2,3)
recode family3 (2=1) 
replace family3 = 1 if pregnant == 1

rename yeduc yeduc3 
rename enrol enrol3 
rename relstat relstat3
rename age age3
rename east east3
rename ethni ethni3 
rename migstatus migstatus3

keep id family3 yeduc3 enrol3 relstat3 age3 ethni3 migstatus3 east3

save "c:\daten\var_wave3" 


***************************************
*** Variables wave 4 ******************
***************************************

use "c:\daten\anchor4.dta", clear

keep if demodiff == 0


* Filtering of network persons (nuclear family, kin, friends & acquaintances)

recode net5p1 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter1) 
recode net5p2 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter2) 
recode net5p3 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter3) 
recode net5p4 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter4) 
recode net5p5 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter5) 
recode net5p6 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter6) 
recode net5p7 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter7) 
recode net5p8 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter8) 
recode net5p9 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter9) 
recode net5p10 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter10) 
recode net5p11 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter11) 
recode net5p12 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter12) 
recode net5p13 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter13) 
recode net5p14 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter14) 
recode net5p15 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter15) 
recode net5p16 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter16) 
recode net5p17 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter17) 
recode net5p18 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter18) 
recode net5p19 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter19) 
recode net5p20 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter20) 
recode net5p21 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter21) 
recode net5p22 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter22) 
recode net5p23 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter23) 
recode net5p24 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter24) 
recode net5p25 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter25) 
recode net5p26 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter26) 
recode net5p27 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter27) 
recode net5p28 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter28) 
recode net5p29 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter29) 
recode net5p30 (2/7 = 1) (12/20 = 1) (21 = 1) (else = 0), gen(filter30)


* Network size

egen size4 = anycount(netp1n netp2n netp3n netp4n netp5n netp6n netp7n netp8n netp9n netp10n netp11n netp12n netp13n netp14n netp15n netp16n ///
netp17n netp18n netp19n netp20n netp21n netp22n netp23n netp24n netp25n netp26n netp27n netp28n netp29n netp30n), values(1)


* Type of relationship 

egen bez_nw_size = anycount(net5p1 net5p2 net5p3 net5p4 net5p5 net5p6 net5p7 net5p8 net5p9 net5p10 net5p11 net5p12 net5p13 net5p14 net5p15 ///
net5p16 net5p17 net5p18 net5p19 net5p20 net5p21 net5p22 net5p23 net5p24 net5p25 net5p26 net5p27 net5p28 net5p29 net5p30), values(2/21)

egen nufam_size = anycount(net5p1 net5p2 net5p3 net5p4 net5p5 net5p6 net5p7 net5p8 net5p9 net5p10 net5p11 net5p12 net5p13 net5p14 net5p15 ///
net5p16 net5p17 net5p18 net5p19 net5p20 net5p21 net5p22 net5p23 net5p24 net5p25 net5p26 net5p27 net5p28 net5p29 ///
net5p30) if bez_nw_size > 0 & bez_nw_size < 31, values(3,4,12)

egen kin_size = anycount(net5p1 net5p2 net5p3 net5p4 net5p5 net5p6 net5p7 net5p8 net5p9 net5p10 net5p11 net5p12 net5p13 net5p14 net5p15 ///
net5p16 net5p17 net5p18 net5p19 net5p20 net5p21 net5p22 net5p23 net5p24 net5p25 net5p26 net5p27 net5p28 net5p29 ///
net5p30) if bez_nw_size > 0 & bez_nw_size < 31, values(5, 6, 7, 13, 14, 15, 16, 17, 18, 19, 20)

egen friend_size = anycount(net5p1 net5p2 net5p3 net5p4 net5p5 net5p6 net5p7 net5p8 net5p9 net5p10 net5p11 net5p12 net5p13 net5p14 net5p15 ///
net5p16 net5p17 net5p18 net5p19 net5p20 net5p21 net5p22 net5p23 net5p24 net5p25 net5p26 net5p27 net5p28 net5p29 ///
net5p30) if bez_nw_size > 0 & bez_nw_size < 31, values(2, 21)

gen p_nufam4 = nufam_size / bez_nw_size
gen p_kin4 = kin_size / bez_nw_size
gen p_friend4 = friend_size / bez_nw_size

replace p_nufam4 = 0 if bez_nw_size == 0 
replace p_kin4 = 0 if bez_nw_size == 0 
replace p_friend4 = 0 if bez_nw_size == 0


* Average age of network

recode net10p1 net10p2 net10p3 net10p4 net10p5 net10p6 net10p7 net10p8 net10p9 net10p10 net10p11 net10p12 net10p13 net10p14 net10p15 ///
net10p16 net10p17 net10p18 net10p19 net10p20 net10p21 net10p22 net10p23 net10p24 net10p25 net10p26 net10p27 net10p28 (-5/-1 = .) 

gen age1 = net10p1 if filter1 == 1
gen age2 = net10p2 if filter2 == 1
gen age3 = net10p3 if filter3 == 1
gen ax4 = net10p4 if filter4 == 1
gen age5 = net10p5 if filter5 == 1
gen age6 = net10p6 if filter6 == 1
gen age7 = net10p7 if filter7 == 1
gen age8 = net10p8 if filter8 == 1
gen age9 = net10p9 if filter9 == 1
gen age10 = net10p10 if filter10 == 1
gen age11 = net10p11 if filter11 == 1
gen age12 = net10p12 if filter12 == 1
gen age13 = net10p13 if filter13 == 1
gen age14 = net10p14 if filter14 == 1
gen age15 = net10p15 if filter15 == 1
gen age16 = net10p16 if filter16 == 1
gen age17 = net10p17 if filter17 == 1
gen age18 = net10p18 if filter18 == 1
gen age19 = net10p19 if filter19 == 1
gen age20 = net10p20 if filter20 == 1
gen age21 = net10p21 if filter21 == 1
gen age22 = net10p22 if filter22 == 1
gen age23 = net10p23 if filter23 == 1
gen age24 = net10p24 if filter24 == 1
gen age25 = net10p25 if filter25 == 1
gen age26 = net10p26 if filter26 == 1
gen age27 = net10p27 if filter27 == 1
gen age28 = net10p28 if filter28 == 1

egen avg_age4 = rowmean(age1 age2 age3 ax4 age5 age6 age7 age8 age9 age10 age11 age12 age13 age14 age15 age16 age17 age18 age19 age20 ///
age21 age22 age23 age24 age25 age26 age27 age28)

egen agesd4 = rowsd(age1 age2 age3 ax4 age5 age6 age7 age8 age9 age10 age11 age12 age13 age14 age15 age16 age17 age18 age19 age20 ///
age21 age22 age23 age24 age25 age26 age27 age28)


* Average duration of relationship 

recode net13p1 net13p2 net13p3 net13p4 net13p5 net13p6 net13p7 net13p8 net13p9 net13p10 net13p11 net13p12 net13p13 net13p14 ///
net13p15 net13p16 net13p17 net13p18 net13p19 net13p20 net13p21 net13p22 net13p23 net13p24 net13p25 net13p26 net13p27 ///
net13p28 (97 = 0)

recode net13p1 net13p2 net13p3 net13p4 net13p5 net13p6 net13p7 net13p8 net13p9 net13p10 net13p11 net13p12 net13p13 net13p14 ///
net13p15 net13p16 net13p17 net13p18 net13p19 net13p20 net13p21 net13p22 net13p23 net13p24 net13p25 net13p26 net13p27 ///
net13p28 (-5/-1 = .) 

gen dur1 = net13p1 if filter1 == 1
gen dur2 = net13p2 if filter2 == 1
gen dur3 = net13p3 if filter3 == 1
gen dur4 = net13p4 if filter4 == 1
gen dur5 = net13p5 if filter5 == 1
gen dur6 = net13p6 if filter6 == 1
gen dur7 = net13p7 if filter7 == 1
gen dur8 = net13p8 if filter8 == 1
gen dur9 = net13p9 if filter9 == 1
gen dur10 = net13p10 if filter10 == 1
gen dur11 = net13p11 if filter11 == 1
gen dur12 = net13p12 if filter12 == 1
gen dur13 = net13p13 if filter13 == 1
gen dur14 = net13p14 if filter14 == 1
gen dur15 = net13p15 if filter15 == 1
gen dur16 = net13p16 if filter16 == 1
gen dur17 = net13p17 if filter17 == 1
gen dur18 = net13p18 if filter18 == 1
gen dur19 = net13p19 if filter19 == 1
gen dur20 = net13p20 if filter20 == 1
gen dur21 = net13p21 if filter21 == 1
gen dur22 = net13p22 if filter22 == 1
gen dur23 = net13p23 if filter23 == 1
gen dur24 = net13p24 if filter24 == 1
gen dur25 = net13p25 if filter25 == 1
gen dur26 = net13p26 if filter26 == 1
gen dur27 = net13p27 if filter27 == 1
gen dur28 = net13p28 if filter28 == 1

egen avg_dur4 = rowmean(dur1 dur2 dur3 dur4 dur5 dur6 dur7 dur8 dur9 dur10 dur11 dur12 dur13 dur14 dur15 dur16 dur17 dur18 dur19 dur20 ///
dur21 dur22 dur23 dur24 dur25 dur26 dur27 dur28)


* Average emotional closeness 

recode net7p1 net7p2 net7p3 net7p4 net7p5 net7p6 net7p7 net7p8 net7p9 net7p10 net7p11 net7p12 net7p13 net7p14 net7p15 net7p16 net7p17 /// 
net7p18 net7p19 net7p20 net7p21 net7p22 net7p23 net7p24 net7p25 net7p26 net7p27 net7p28 (-5/-1 = .)

gen nah1 = net7p1 if filter1 == 1
gen nah2 = net7p2 if filter2 == 1
gen nah3 = net7p3 if filter3 == 1
gen nah4 = net7p4 if filter4 == 1
gen nah5 = net7p5 if filter5 == 1
gen nah6 = net7p6 if filter6 == 1
gen nah7 = net7p7 if filter7 == 1
gen nah8 = net7p8 if filter8 == 1
gen nah9 = net7p9 if filter9 == 1
gen nah10 = net7p10 if filter10 == 1
gen nah11 = net7p11 if filter11 == 1
gen nah12 = net7p12 if filter12 == 1
gen nah13 = net7p13 if filter13 == 1
gen nah14 = net7p14 if filter14 == 1
gen nah15 = net7p15 if filter15 == 1
gen nah16 = net7p16 if filter16 == 1
gen nah17 = net7p17 if filter17 == 1
gen nah18 = net7p18 if filter18 == 1
gen nah19 = net7p19 if filter19 == 1
gen nah20 = net7p20 if filter20 == 1
gen nah21 = net7p21 if filter21 == 1
gen nah22 = net7p22 if filter22 == 1
gen nah23 = net7p23 if filter23 == 1
gen nah24 = net7p24 if filter24 == 1
gen nah25 = net7p25 if filter25 == 1
gen nah26 = net7p26 if filter26 == 1
gen nah27 = net7p27 if filter27 == 1
gen nah28 = net7p28 if filter28 == 1

egen avg_close4 = rowmean(nah1 nah2 nah3 nah4 nah5 nah6 nah7 nah8 nah9 nah10 nah11 nah12 nah13 nah14 nah15 nah16 nah17 nah18 nah19 nah20 ///
nah21 nah22 nah23 nah24 nah25 nah26 nah27 nah28)


* Potential for emotional contagion 

gen cont1 = 1 if net10p1 > 13 & net10p1 < 46 & (net5p1 == 12 | net5p1 == 14 | net5p1 == 15 | net5p1 == 16 | net5p1 == 17 | net5p1 == 19 | ///
net5p1 == 20 | net5p1 == 21) 

gen cont2 = 1 if net10p2 > 13 & net10p2 < 46 & (net5p2 == 12 | net5p2 == 14 | net5p2 == 15 | net5p2 == 16 | net5p2 == 17 | net5p2 == 19 | ///
net5p2 == 20 | net5p2 == 21)

gen cont3 = 1 if net10p3 > 13 & net10p3 < 46 & (net5p3 == 12 | net5p3 == 14 | net5p3 == 15 | net5p3 == 16 | net5p3 == 17 | net5p3 == 19 | ///
net5p3 == 20 | net5p3 == 21)

gen cont4 = 1 if net10p4 > 13 & net10p4 < 46 & (net5p4 == 12 | net5p4 == 14 | net5p4 == 15 | net5p4 == 16 | net5p4 == 17 | net5p4 == 19 | ///
net5p4 == 20 | net5p4 == 21)

gen cont5 = 1 if net10p5 > 13 & net10p5 < 46 & (net5p5 == 12 | net5p5 == 14 | net5p5 == 15 | net5p5 == 16 | net5p5 == 17 | net5p5 == 19 | ///
net5p5 == 20 | net5p5 == 21)

gen cont6 = 1 if net10p6 > 13 & net10p6 < 46 & (net5p6 == 12 | net5p6 == 14 | net5p6 == 15 | net5p6 == 16 | net5p6 == 17 | net5p6 == 19 | ///
net5p6 == 20 | net5p6 == 21)

gen cont7 = 1 if net10p7 > 13 & net10p7 < 46 & (net5p7 == 12 | net5p7 == 14 | net5p7 == 15 | net5p7 == 16 | net5p7 == 17 | net5p7 == 19 | ///
net5p7 == 20 | net5p7 == 21)

gen cont8 = 1 if net10p8 > 13 & net10p8 < 46 & (net5p8 == 12 | net5p8 == 14 | net5p8 == 15 | net5p8 == 16 | net5p8 == 17 | net5p8 == 19 | ///
net5p8 == 20 | net5p8 == 21)

gen cont9 = 1 if net10p9 > 13 & net10p9 < 46 & (net5p9 == 12 | net5p9 == 14 | net5p9 == 15 | net5p9 == 16 | net5p9 == 17 | net5p9 == 19 | ///
net5p9 == 20 | net5p9 == 21)

gen cont10 = 1 if net10p10 > 13 & net10p10 < 46 & (net5p10 == 12 | net5p10 == 14 | net5p10 == 15 | net5p10 == 16 | net5p10 == 17 | net5p10 == 19 | ///
net5p10 == 20 | net5p10 == 21)

gen cont11 = 1 if net10p11 > 13 & net10p11 < 46 & (net5p11 == 12 | net5p11 == 14 | net5p11 == 15 | net5p11 == 16 | net5p11 == 17 | net5p11 == 19 | ///
net5p11 == 20 | net5p11 == 21)

gen cont12 = 1 if net10p12 > 13 & net10p12 < 46 & (net5p12 == 12 | net5p12 == 14 | net5p12 == 15 | net5p12 == 16 | net5p12 == 17 | net5p12 == 19 | ///
net5p12 == 20 | net5p12 == 21)

gen cont13 = 1 if net10p13 > 13 & net10p13 < 46 & (net5p13 == 12 | net5p13 == 14 | net5p13 == 15 | net5p13 == 16 | net5p13 == 17 | net5p13 == 19 | ///
net5p13 == 20 | net5p13 == 21)

gen cont14 = 1 if net10p14 > 13 & net10p14 < 46 & (net5p14 == 12 | net5p14 == 14 | net5p14 == 15 | net5p14 == 16 | net5p14 == 17 | net5p14 == 19 | ///
net5p14 == 20 | net5p14 == 21)

gen cont15 = 1 if net10p15 > 13 & net10p15 < 46 & (net5p15 == 12 | net5p15 == 14 | net5p15 == 15 | net5p15 == 16 | net5p15 == 17 | net5p15 == 19 | ///
net5p15 == 20 | net5p15 == 21)

gen cont16 = 1 if net10p16 > 13 & net10p16 < 46 & (net5p16 == 12 | net5p16 == 14 | net5p16 == 15 | net5p16 == 16 | net5p16 == 17 | net5p16 == 19 | ///
net5p16 == 20 | net5p16 == 21)

gen cont17 = 1 if net10p17 > 13 & net10p17 < 46 & (net5p17 == 12 | net5p17 == 14 | net5p17 == 15 | net5p17 == 16 | net5p17 == 17 | net5p17 == 19 | ///
net5p17 == 20 | net5p17 == 21)

gen cont18 = 1 if net10p18 > 13 & net10p18 < 46 & (net5p18 == 12 | net5p18 == 14 | net5p18 == 15 | net5p18 == 16 | net5p18 == 17 | net5p18 == 19 | ///
net5p18 == 20 | net5p18 == 21)

gen cont19 = 1 if net10p19 > 13 & net10p19 < 46 & (net5p19 == 12 | net5p19 == 14 | net5p19 == 15 | net5p19 == 16 | net5p19 == 17 | net5p19 == 19 | ///
net5p19 == 20 | net5p19 == 21)

gen cont20 = 1 if net10p20 > 13 & net10p20 < 46 & (net5p20 == 12 | net5p20 == 14 | net5p20 == 15 | net5p20 == 16 | net5p20 == 17 | net5p20 == 19 | ///
net5p20 == 20 | net5p20 == 21)

gen cont21 = 1 if net10p21 > 13 & net10p21 < 46 & (net5p21 == 12 | net5p21 == 14 | net5p21 == 15 | net5p21 == 16 | net5p21 == 17 | net5p21 == 19 | ///
net5p21 == 20 | net5p21 == 21)

gen cont22 = 1 if net10p22 > 13 & net10p22 < 46 & (net5p22 == 12 | net5p22 == 14 | net5p22 == 15 | net5p22 == 16 | net5p22 == 17 | net5p22 == 19 | ///
net5p22 == 20 | net5p22 == 21)

gen cont23 = 1 if net10p23 > 13 & net10p23 < 46 & (net5p23 == 12 | net5p23 == 14 | net5p23 == 15 | net5p23 == 16 | net5p23 == 17 | net5p23 == 19 | ///
net5p23 == 20 | net5p23 == 21)

gen cont24 = 1 if net10p24 > 13 & net10p24 < 46 & (net5p24 == 12 | net5p24 == 14 | net5p24 == 15 | net5p24 == 16 | net5p24 == 17 | net5p24 == 19 | ///
net5p24 == 20 | net5p24 == 21)

gen cont25 = 1 if net10p25 > 13 & net10p25 < 46 & (net5p25 == 12 | net5p25 == 14 | net5p25 == 15 | net5p25 == 16 | net5p25 == 17 | net5p25 == 19 | ///
net5p25 == 20 | net5p25 == 21)

gen cont26 = 1 if net10p26 > 13 & net10p26 < 46 & (net5p26 == 12 | net5p26 == 14 | net5p26 == 15 | net5p26 == 16 | net5p26 == 17 | net5p26 == 19 | ///
net5p26 == 20 | net5p26 == 21)

gen cont27 = 1 if net10p27 > 13 & net10p27 < 46 & (net5p27 == 12 | net5p27 == 14 | net5p27 == 15 | net5p27 == 16 | net5p27 == 17 | net5p27 == 19 | ///
net5p27 == 20 | net5p27 == 21)

gen cont28 = 1 if net10p28 > 13 & net10p28 < 46 & (net5p28 == 12 | net5p28 == 14 | net5p28 == 15 | net5p28 == 16 | net5p28 == 17 | net5p28 == 19 | ///
net5p28 == 20 | net5p28 == 21)

recode net12p1-net12p23 (-7/-1=.)
recode net12p25-net12p26 (-7/-1=.)
recode net12p28 (-7/-1=.)

gen cont_1 = net12p1 if cont1 == 1
gen cont_2 = net12p2 if cont2 == 1
gen cont_3 = net12p3 if cont3 == 1
gen cont_4 = net12p4 if cont4 == 1
gen cont_5 = net12p5 if cont5 == 1
gen cont_6 = net12p6 if cont6 == 1
gen cont_7 = net12p7 if cont7 == 1
gen cont_8 = net12p8 if cont8 == 1
gen cont_9 = net12p9 if cont9 == 1
gen cont_10 = net12p10 if cont10 == 1
gen cont_11 = net12p11 if cont11 == 1
gen cont_12 = net12p12 if cont12 == 1
gen cont_13 = net12p13 if cont13 == 1
gen cont_14 = net12p14 if cont14 == 1
gen cont_15 = net12p15 if cont15 == 1
gen cont_16 = net12p16 if cont16 == 1
gen cont_17 = net12p17 if cont17 == 1
gen cont_18 = net12p18 if cont18 == 1
gen cont_19 = net12p19 if cont19 == 1
gen cont_20 = net12p20 if cont20 == 1
gen cont_21 = net12p21 if cont21 == 1
gen cont_22 = net12p22 if cont22 == 1
gen cont_23 = net12p23 if cont23 == 1
gen cont_25 = net12p25 if cont25 == 1
gen cont_26 = net12p26 if cont26 == 1
gen cont_28 = net12p28 if cont28 == 1

egen cont_nw_size = anycount(cont_1 cont_2 cont_3 cont_4 cont_5 cont_6 cont_7 cont_8 cont_9 cont_10 cont_11 cont_12 cont_13 cont_14 cont_15 ///
cont_16 cont_17 cont_18 cont_19 cont_20 cont_21 cont_22 cont_23 cont_25 cont_26 cont_28), values(0/5) 

egen n_nw_kids = anycount(cont_1 cont_2 cont_3 cont_4 cont_5 cont_6 cont_7 cont_8 cont_9 cont_10 cont_11 cont_12 cont_13 cont_14 cont_15 ///
cont_16 cont_17 cont_18 cont_19 cont_20 cont_21 cont_22 cont_23 cont_25 cont_26 cont_28), values(1/5)

gen p_contag4 = n_nw_kids / cont_nw_size

replace p_contag4 = 0 if cont_nw_size == 0

recode p_contag4 (else = .) if age < 18

egen m_contag4 = rowmean(cont_1 cont_2 cont_3 cont_4 cont_5 cont_6 cont_7 cont_8 cont_9 cont_10 cont_11 cont_12 cont_13 cont_14 cont_15 ///
cont_16 cont_17 cont_18 cont_19 cont_20 cont_21 cont_22 cont_23 cont_25 cont_26 cont_28)

replace p_contag4 = . if m_contag4 == .


* Diversity
 
recode net5p1 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p1)
recode net5p2 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p2)
recode net5p3 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p3)
recode net5p4 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p4)
recode net5p5 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p5)
recode net5p6 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p6)
recode net5p7 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p7)
recode net5p8 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p8)
recode net5p9 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p9)
recode net5p10 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p10)
recode net5p11 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p11)
recode net5p12 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p12)
recode net5p13 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p13)
recode net5p14 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p14)
recode net5p15 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p15)
recode net5p16 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p16)
recode net5p17 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p17)
recode net5p18 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p18)
recode net5p19 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p19)
recode net5p20 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p20)
recode net5p21 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p21)
recode net5p22 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p22)
recode net5p23 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p23)
recode net5p24 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p24)
recode net5p25 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p25)
recode net5p26 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p26)
recode net5p27 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p27)
recode net5p28 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p28)
recode net5p29 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p29)
recode net5p30 (3 = 1) (4 = 1) (12 = 1) (2 = 3) (21 = 3) (5/7 = 2) (13/20 = 2) (else = .), gen(rt_p30)


* Social pressure (global question)

recode frt10i1 frt10i2 (-5/-1 = .) 
 
corr frt10i1 frt10i2

egen pressure4 = rowmean(frt10i1 frt10i2)



* Social support (global question)

recode frt20i1 frt20i2 frt20i3 (-5/-1=.) (7=.) 

alpha frt20i1 frt20i2 frt20i3, item  

egen support4 = rowmean(frt20i1 frt20i2 frt20i3)


* Saving 

rename age age4 
rename ethni ethni4 
rename migstatus migstatus4
rename relstat relstat4
rename yeduc yeduc4
rename enrol enrol4
rename east east4 

egen family4 = anycount(crn3k1-crn3k7), values(-1,-2,1,2,3)
recode family4 (2=1) 
replace family4 = 1 if pregnant == 1

merge 1:1 id using "c:\daten\filter2", keep(match master)

gen filter_w4 = 1 
replace filter_w4 = 0 if homosex == 1 | pregnant == 1 | nkids > 0 | nkids == -7 | infertile == 1 | age4 < 20
replace filter_w4 = 1 if filter_w2 == 1 & family4 == 1

keep if filter_w4 == 1

keep id rt_p1-rt_p30 size4 p_nufam4 p_kin4 p_friend4 avg_age4 agesd4 avg_dur4 avg_close4 p_contag4 m_contag4 pressure4 support4 ///
age4 ethni4 migstatus4 relstat4 yeduc4 enrol4 east4 family4

save "c:\daten\var_wave4.dta"


* Computing "index of qualitative variation"  

use "c:\daten\var_wave4.dta", clear

keep id rt_p1-rt_p30

reshape long rt_p, i(id) j(np)

gen ntyp = 0
replace ntyp = 1 if rt_p <= 3
by id: replace ntyp = sum(ntyp)
by id: replace ntyp = ntyp[_N]

local i = 1
while `i' < 4 {
gen pbt_k`i' = 1 if rt_p == `i'
by id: replace pbt_k`i' = sum(pbt_k`i')/ntyp
by id: replace pbt_k`i' = pbt_k`i'[_N]
local i = `i' + 1
}

gen helpv = pbt_k1^2+pbt_k2^2+pbt_k3^2
gen helpv2 = 1
gen dbt = helpv2-helpv 

gen iqv4 = 3/2*dbt

by id: gen ln = _n

keep if ln == 1
keep id iqv4 

save "c:\daten\iqv_w4.dta" 


* Merge

use "c:\daten\var_wave2.dta", clear

merge 1:1 id using "c:\daten\var_wave4.dta"

drop _merge 

merge 1:1 id using "c:\daten\iqv_w2.dta", keep(match master)

drop _merge

merge 1:1 id using "c:\daten\iqv_w4.dta", keep(match master)

drop _merge 

merge 1:1 id using "c:\daten\var_wave3.dta", keep(match master)

drop _merge

merge 1:1 id using "c:\daten\sib.dta", keep(match master)

save "c:\daten\merged.dta" 


********************************************************
*** Cluster analysis (pooled wave 2 and wave 4 data) ***
********************************************************

* Long format

gen trans = 0
replace trans = 1 if (family3 == 1 | family4 == 1)
replace trans = 0 if age4 == 20 | age4 == 21

drop age3 ethni3 migstatus3 relstat3 enrol3 yeduc3 east3 family3 rt_p1-rt_p30 filter _merge

rename age age1 
rename age4 age2 
rename ethni ethni1 
rename ethni4 ethni2 
rename migstatus migstatus1 
rename migstatus4 migstatus2
rename relstat relstat1 
rename relstat4 relstat2 
rename enrol enrol1 
rename enrol4 enrol2 
rename yeduc yeduc1
rename yeduc4 yeduc2 
rename east east1 
rename east4 east2 
rename size size1 
rename size4 size2 
rename p_nufam p_nufam1
rename p_nufam4 p_nufam2 
rename p_kin p_kin1
rename p_kin4 p_kin2 
rename p_friend p_friend1
rename p_friend4 p_friend2
rename avg_age avg_age1 
rename avg_age4 avg_age2 
rename agesd agesd1
rename agesd4 agesd2
rename avg_dur avg_dur1 
rename avg_dur4 avg_dur2 
rename avg_close avg_close1 
rename avg_close4 avg_close2 
rename p_contag p_contag1
rename p_contag4 p_contag2 
rename m_contag m_contag1 
rename m_contag4 m_contag2
rename pressure pressure1 
rename pressure4 pressure2 
rename support support1
rename support4 support2 
rename iqv iqv1
rename iqv4 iqv2

reshape long age ethni migstatus relstat enrol yeduc east size p_nufam p_kin p_friend avg_age agesd ///
avg_dur avg_close p_contag m_contag pressure support iqv, i(id) j(wave)


* Imputation 

drop if age == .

recode igr19 (-2=.) (-1=.)
recode sex_gen (1=1) (2=0) (-4=.), gen(male)
recode ethni (-7=.)
recode migstatus (-7=.)
recode relstat (-7=.) 
recode yeduc (-7=.)
recode enrol (-7=.) (0=0) (1/16=1) 
recode migstatus (1=0) (2/3=1), gen(migration)
recode agesd (else = 0) if size == 0

impute avg_age age yeduc east p_nufam p_kin p_friend avg_dur avg_close p_contag ///
m_contag pressure support iqv igr19 male migration size, generate(avg_age2)

impute agesd age yeduc east p_nufam p_kin p_friend avg_dur avg_close p_contag ///
m_contag pressure support iqv igr19 male migration size, generate(agesd2)

impute avg_dur age yeduc east p_nufam p_kin p_friend avg_age avg_close p_contag ///
m_contag pressure support iqv igr19 male migration size, generate(avg_dur2)

impute avg_close age yeduc east p_nufam p_kin p_friend avg_age avg_dur p_contag ///
m_contag pressure support iqv igr19 male migration size, generate(avg_close2)

impute p_contag age yeduc east p_nufam p_kin p_friend avg_age avg_dur avg_close ///
m_contag pressure support iqv igr19 male migration size, generate(p_contag2)

impute m_contag age yeduc east p_nufam p_kin p_friend avg_age avg_dur avg_close ///
p_contag pressure support iqv igr19 male migration size, generate(m_contag2)

impute pressure age yeduc east p_nufam p_kin p_friend avg_age avg_dur avg_close ///
p_contag m_contag support iqv igr19 male migration size, generate(pressure2)

impute support age yeduc east p_nufam p_kin p_friend avg_age avg_dur avg_close ///
p_contag m_contag pressure iqv igr19 male migration size, generate(support2)

impute iqv age yeduc east p_nufam p_kin p_friend avg_age avg_dur avg_close ///
p_contag m_contag pressure support igr19 male migration size, generate(iqv2)

impute igr19 age yeduc east p_nufam p_kin p_friend avg_age avg_dur avg_close ///
p_contag m_contag pressure support iqv male migration size, generate(siblings)

recode p_contag2 m_contag2 iqv2(-1/0=0) 
recode pressure2 (0/1=1)
recode agesd2 (-10/0=0)


* Cluster analyses 

gen contag_w = p_contag2 / age
gen dur_w = avg_dur2 / age
gen nwage_w = avg_age2 / age 

egen m_agez = std(nwage_w)
egen m_durz = std(avg_dur2)
egen m_durz2 = std(dur_w) 
egen m_closez = std(avg_close2) 
egen press_z = std(pressure2) 
egen supp_z = std(support2)
egen sib_z = std(siblings) 
egen iqv_z = std(iqv2) 
egen cont_z = std(contag_w)
egen cont_z2 = std(p_contag2)
egen contm_z = std(m_contag2) 
egen pnu_z = std(p_nufam) 
egen pkin_z = std(p_kin)
egen pfriend_z = std(p_friend) 
egen agesd_z = std(agesd2)
egen size_z = std(size)


cluster wardslinkage supp_z press_z cont_z pnu_z pkin_z pfriend_z iqv_z size_z m_closez agesd_z m_agez m_durz, measure(l2squared) name(clu1)

cluster stop

cluster generate g4 = groups(4), name(clu1)

cluster kmeans supp_z press_z cont_z pnu_z pkin_z pfriend_z iqv_z size_z m_closez agesd_z m_agez m_durz, ///
k(4) start(group(g4)) measure(linfinity) name(kclu1)

* Table 1

bysort kclu1: sum supp_z press_z cont_z pnu_z pkin_z pfriend_z iqv_z size_z m_closez agesd_z m_agez m_durz

cluster generate g3 = groups(3), name(clu1)
cluster generate g5 = groups(5), name(clu1)

bysort g3: sum supp_z press_z cont_z pnu_z pkin_z pfriend_z iqv_z size_z m_closez agesd_z m_agez m_durz
bysort g5: sum supp_z press_z cont_z pnu_z pkin_z pfriend_z iqv_z size_z m_closez agesd_z m_agez m_durz


******************************************************************
*** Stability of cluster membership over time (wave 2 - wave 4) **
******************************************************************

keep id wave kclu1 trans

reshape wide kclu, i(id) j(wave)

* Table 2 and Table 3

tab2 kclu11 kclu12 if trans == 0, exp row column V
tab2 kclu11 kclu12 if trans == 1, exp row column V

gen stability = 0 if kclu11 < . & kclu12 < .
replace stability = 1 if kclu11 == kclu12

* ssc install emh

* emh kclu11 kclu12, general strata(trans)

save "c:\daten\cluster.dta"


***************************************
*** Variables wave 5 ******************
***************************************

use "c:\daten\anchor5.dta", clear 

keep if demodiff == 0

egen family5 = anycount(crn3k1-crn3k5), values(1,2,3)
recode family5 (2=1) 
replace family5 = 1 if pregnant == 1

rename yeduc yeduc5 
rename enrol enrol5 
rename relstat relstat5
rename age age5
rename east east5
rename ethni ethni5 
rename migstatus migstatus5

keep id family5 yeduc5 enrol5 relstat5 age5 ethni5 migstatus5 east5

save "c:\daten\var_wave5.dta" 


***************************************
*** Variables wave 6 ******************
***************************************

use "c:\daten\anchor6.dta", clear 

keep if demodiff == 0

egen family6 = anycount(crn3k1-crn3k6), values(-1,-2,1,2,3)
recode family6 (2=1) (3=1)
replace family6 = 1 if pregnant == 1

keep id family6

save "c:\daten\var_wave6.dta" 


******************************************************************
*** Discrete time event history analyses *************************
******************************************************************

use "c:\daten\merged.dta" 

drop _merge rt_p1-rt_p30

merge 1:1 id using "c:\daten\cluster.dta", keep(match master)

drop _merge

merge 1:1 id using "c:\daten\var_wave5.dta", keep(match master)

drop _merge

merge 1:1 id using "c:\daten\var_wave6.dta", keep(match master)

gen clus1 = kclu11
gen clus2 = kclu11 
gen clus3 = kclu12 
gen clus4 = kclu12

rename age age1
rename age3 age2 
rename age4 age3 
rename age5 age4

rename migstatus migstatus1
rename migstatus3 migstatus2
rename migstatus4 migstatus3
rename migstatus5 migstatus4

rename enrol enrol1 
rename enrol3 enrol2 
rename enrol4 enrol3 
rename enrol5 enrol4

rename yeduc yeduc1 
rename yeduc3 yeduc2 
rename yeduc4 yeduc3 
rename yeduc5 yeduc4

rename east east1
rename east3 east2
rename east4 east3
rename east5 east4

rename relstat relstat1
rename relstat3 relstat2
rename relstat4 relstat3
rename relstat5 relstat4 

gen nwage1 = avg_age 
gen nwage2 = avg_age + 1 
gen nwage3 = avg_age4 
gen nwage4 = avg_age4 + 1

gen birth1 = 0 if age1 < .
replace birth1 = 1 if family3 == 1

gen birth2 = 0 if age2 < . & birth1 == 0 & family4 == 0 
replace birth2 = 1 if birth1 == 0 & family4 == 1

gen birth3 = 0 if age3 < . & family3 == 0 & family4 == 0 & family5 == 0
replace birth3 = 1 if birth2 == 0 & family5 == 1

gen birth4 = 0 if age4 < . & family3 == 0 & family4 == 0 & family5 == 0 & family6 == 0
replace birth4 = 1 if birth3 == 0 & family6 == 1

replace birth3 = 0 if age3 < 23 & family5 == 0 & age3 < .
replace birth3 = 1 if age4 < 23 & family5 == 1 & age3 < .

replace birth4 = 0 if age3 < 23 & family5 == 0 & family6 == 0 & age4 < . 
replace birth4 = 1 if age4 < 23 & family5 == 0 & family6 == 1 & age4 < .

drop ethni size p_nufam p_kin p_friend agesd avg_dur avg_close p_contag m_contag pressure ///
support filter_w2 ethni4 size4 p_nufam4 p_kin4 p_friend4 avg_age4 agesd4 avg_dur4 avg_close4 ///
p_contag4 m_contag4 pressure4 support4 family4 iqv iqv4 ethni3 ethni5 family5 family6 _merge ///
avg_age kclu11 kclu12 family3

reshape long age migstatus relstat enrol yeduc east birth clus nwage, i(id) j(wave)

keep if birth < . & age < .

recode igr19 (-2=.) (-1=.), gen(sibl) 

recode relstat (1=1) (6=1) (9=1) (-7=.) (else=0), gen(single) 
recode relstat (2=1) (5=1) (7=1) (-7=.) (else=0), gen(lat)
recode relstat (3=1) (8=1) (-7=.) (else=0), gen(nel) 
recode relstat (4=1) (-7=.) (else=0), gen(marr) 

recode migstatus (1=0) (2/3=1) (-7=.)

recode enrol (-7=.) (0=0) (1/16=1)

recode yeduc (-7=.) (0=.)

recode east (-7=.) 

recode sex_gen (1=1) (2=0) (-4=.), gen(male)

recode clus (1=1) (else=0), gen(famcent) 
recode clus (2=1) (else=0), gen(famrem) 
recode clus (3=1) (else=0), gen(desint)
recode clus (4=1) (else=0), gen(polar)

impute nwage famcent famrem desint sibl age yeduc enrol east lat nel marr single migstatus male, generate(nwage2)
impute yeduc famcent famrem desint sibl age enrol east lat nel marr single migstatus male nwage, generate(yeduc2)
impute enrol famcent famrem desint sibl age yeduc east lat nel marr single migstatus male nwage, generate(enrol2)
impute lat famcent famrem desint sibl age enrol east yeduc nel marr single migstatus male nwage, generate(lat2)
impute nel famcent famrem desint sibl age enrol east yeduc lat marr single migstatus male nwage, generate(nel2)
impute marr famcent famrem desint sibl age enrol east yeduc lat nel single migstatus male nwage, generate(marr2)
impute single famcent famrem desint sibl age enrol east yeduc lat nel marr migstatus male nwage, generate(single2)
impute east famcent famrem desint sibl age enrol yeduc lat nel marr single migstatus male nwage, generate(east2)
impute sibl famcent famrem desint east age enrol yeduc lat nel marr single migstatus male nwage, generate(sibl2)
impute male famcent famrem desint east age enrol yeduc lat nel marr single migstatus sibl nwage, generate(male2)
impute migstatus famcent famrem desint east age enrol yeduc lat nel marr single male sibl nwage, generate(mig2)

sum nwage2 yeduc2 enrol2 lat2 nel2 marr2 single2 east2 sibl2 male2

recode enrol2 lat2 nel2 marr2 single2 east2 male2 mig2 (-5/0.4999=0) (0.5/5=1)

sum age nwage 

gen agez = age - 28.7
gen ageq = agez*agez

gen nwagez = nwage2 - 30.6 
gen nwaq = nwagez*nwagez

recode stability (1=0) (0=1), gen(inst)

gen yeduxm = yeduc2*male2 
gen eastxm = east2*marr2 
gen famcxs = famcent*inst
gen famrxs = famrem*inst 
gen desxs = desint*inst
gen polxs = polar*inst


* Table 4, Model 1 

logit birth agez ageq nwagez nwaq famcent desint polar

* Model 2 

logit birth agez ageq nwagez nwaq famcent desint polar male2 mig2 enrol2 yeduc2 east2 single2 marr2 nel2 yeduxm eastxm sibl2

* Model 3 

logit birth agez ageq nwagez nwaq famcent desint polar male2 mig2 enrol2 yeduc2 east2 single2 marr2 nel2 yeduxm eastxm sibl2 ///
famcxs polxs desxs inst





 



 
 







